@@ -16,7 +16,7 @@ our @EXPORT = qw(
 	pause_add_uri
 	);
 
-$VERSION = '2.06_06';
+$VERSION = '2.07_01';
 
 =encoding utf8
 
@@ -68,7 +68,8 @@ sub web_upload {
 
 sub make_agent {
 	my( $self ) = @_;
-	my $agent = Mojo::UserAgent->new( name => 'release' );
+	my $agent = Mojo::UserAgent->new;
+	$agent->transactor->name( 'release' );
 	$agent->http_proxy( $self->config->http_proxy ) if $self->config->http_proxy;
 	$agent->https_proxy( $self->config->https_proxy ) if $self->config->https_proxy;
 	require CACertOrg::CA;
